@@ -35,7 +35,7 @@
 #include <tqcheckbox.h>
 
 // KDE includes
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include <kdialogbase.h>
 #include <kprocess.h>
 #include <tdewallet.h>
@@ -61,7 +61,7 @@ class Smb4KAuthInfo;
  * @author Alexander Reinholdt <dustpuppy@users.berlios.de>
  */
 
-class KDE_EXPORT Smb4KPasswordHandler : public TQObject
+class TDE_EXPORT Smb4KPasswordHandler : public TQObject
 {
   TQ_OBJECT
   
