@@ -36,7 +36,7 @@
 #include <tqptrqueue.h>
 
 // KDE includes
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include <kprocess.h>
 
 // forward declarations
@@ -49,7 +49,7 @@ class Smb4KPreviewItem;
  * @author Alexander Reinholdt <dustpuppy@users.berlios.de>
  */
 
-class KDE_EXPORT Smb4KPreviewer : public TQObject
+class TDE_EXPORT Smb4KPreviewer : public TQObject
 {
   TQ_OBJECT
   
