@@ -35,7 +35,7 @@
 #include <tqmap.h>
 #include <tqpair.h>
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 // application specific includes
 #include "smb4knetworkitems.h"
@@ -49,7 +49,7 @@ typedef TQPair<int, TQString> ContentsItem;
  * @author Alexander Reinholdt <dustpuppy@users.berlios.de>
  */
 
-class KDE_EXPORT Smb4KPreviewItem
+class TDE_EXPORT Smb4KPreviewItem
 {
   public:
     /**
