@@ -36,7 +36,7 @@
 #include <tqwidget.h>
 
 // KDE includes
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include <kdialogbase.h>
 #include <kprocess.h>
 
@@ -53,7 +53,7 @@ class Smb4KPrintInfo;
  * @author Alexander Reinholdt <dustpuppy@users.berlios.de>
  */
 
-class KDE_EXPORT Smb4KPrint : public TQObject
+class TDE_EXPORT Smb4KPrint : public TQObject
 {
   TQ_OBJECT
   
