@@ -33,7 +33,7 @@
 // TQt includes
 #include <tqstring.h>
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 // application specific includes
 #include "smb4knetworkitems.h"
@@ -43,7 +43,7 @@
  * that is needed to print a file.
  */
 
-class KDE_EXPORT Smb4KPrintInfo
+class TDE_EXPORT Smb4KPrintInfo
 {
   public:
     /**
