@@ -35,7 +35,7 @@
 #include <tqmap.h>
 
 // KDE includes
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include <tdeconfig.h>
 
 // forward declarations
@@ -50,7 +50,7 @@ class Smb4KShare;
  * @author Alexander Reinholdt <dustpuppy@mail.berlios.de>
  */
 
-class KDE_EXPORT Smb4KSambaOptionsHandler : public TQObject
+class TDE_EXPORT Smb4KSambaOptionsHandler : public TQObject
 {
   TQ_OBJECT
   
