@@ -34,7 +34,7 @@
 // TQt includes
 #include <tqstring.h>
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 // forward declarations
 class Smb4KShare;
@@ -47,7 +47,7 @@ class Smb4KShare;
  * @author  Alexander Reinholdt <dustpuppy@mail.berlios.de>
  */
 
-class KDE_EXPORT Smb4KSambaOptionsInfo
+class TDE_EXPORT Smb4KSambaOptionsInfo
 {
   public:
     /**
