@@ -35,7 +35,7 @@
 #include <tqcheckbox.h>
 
 // KDE includes
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include <kdialogbase.h>
 #include <knuminput.h>
 #include <kcombobox.h>
@@ -45,7 +45,7 @@
 class Smb4KHostItem;
 class Smb4KShareItem;
 
-class KDE_EXPORT Smb4KCustomOptionsDialog : public KDialogBase
+class TDE_EXPORT Smb4KCustomOptionsDialog : public KDialogBase
 {
   TQ_OBJECT
   
